@@ -1,5 +1,5 @@
 from collections import defaultdict
-from contextlib import ExitStack
+from contextlib import ExitStack, redirect_stdout
 from enum import Enum
 from filecmp import cmp
 from logging import getLogger
@@ -72,6 +72,7 @@ class Builder:
         self._logger.info("Processing standalones")
         for standalone_dir in self._settings.compile_standalones:
             root = self._paths.settings.parent / standalone_dir
+            to_compile.extend((root, latex) for latex in root.glob("**/*.py"))
             to_compile.extend((root, latex) for latex in root.glob("**/*.tex"))
         with Pool() as pool:
             compile_results = pool.starmap(self._compile_standalone, to_compile)
@@ -80,18 +81,36 @@ class Builder:
                 self._logger.warning("Standalone compilation of %s errored", latex_file)
                 self._logger.warning("Captured stderr\n%s", compile_result.stderr)
 
-    def _compile_standalone(self, root: Path, latex_file: Path) -> CompileResult:
-        pdf = (root / "pdf" / latex_file.relative_to(root)).with_suffix(".pdf")
-        if pdf.exists() and pdf.stat().st_mtime > latex_file.stat().st_mtime:
+    def _generate_latex(self, python_file: Path, output_file: Path) -> None:
+        compiled = compile(
+            source=python_file.read_text(encoding="utf8"),
+            filename=python_file.name,
+            mode="exec",
+        )
+        output_file.parent.mkdir(parents=True, exist_ok=True)
+        with output_file.open("w", encoding="utf8") as fh:
+            with redirect_stdout(fh):
+                exec(compiled)
+
+    def _compile_standalone(self, root: Path, input_file: Path) -> CompileResult:
+        pdf = (root / "pdf" / input_file.relative_to(root)).with_suffix(".pdf")
+        if pdf.exists() and pdf.stat().st_mtime > input_file.stat().st_mtime:
             return CompileResult(True)
         with TemporaryDirectory() as build_dir:
             build_path = Path(build_dir)
-            latex_build_file = build_path / latex_file.relative_to(root)
-            self._copy_file(latex_file, latex_build_file)
-            compile_result = self._compile(latex_build_file)
+            build_file = (build_path / input_file.relative_to(root)).with_suffix(".tex")
+            if input_file.suffix == ".py":
+                self._generate_latex(input_file, build_file)
+            elif input_file.suffix == ".tex":
+                self._copy_file(input_file, build_file)
+            else:
+                raise ValueError(
+                    f"Unsupported standalone file extension {input_file.suffix}"
+                )
+            compile_result = self._compile(build_file)
             if compile_result.ok:
                 pdf.parent.mkdir(parents=True, exist_ok=True)
-                copyfile(latex_build_file.with_suffix(".pdf"), pdf)
+                copyfile(build_file.with_suffix(".pdf"), pdf)
         return compile_result
 
     def _list_items(self) -> List[CompileItem]:
