@@ -1,4 +1,5 @@
 from logging import getLogger
+from pathlib import Path
 
 from deckz.cli import app
 from deckz.paths import Paths
@@ -9,7 +10,7 @@ _logger = getLogger(__name__)
 
 
 @app.command()
-def upload(deck_path: str = ".") -> None:
+def upload(deck_path: Path = Path(".")) -> None:
     """Upload pdfs to Google Drive."""
-    paths = Paths(deck_path)
+    paths = Paths.from_defaults(deck_path)
     Uploader(paths)
